===========================
Easy My Coop Easy Migration
===========================

.. !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
   !! This file is generated by oca-gen-addon-readme !!
   !! changes will be overwritten.                   !!
   !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

.. |badge1| image:: https://img.shields.io/badge/maturity-Beta-yellow.png
    :target: https://odoo-community.org/page/development-status
    :alt: Beta
.. |badge2| image:: https://img.shields.io/badge/licence-AGPL--3-blue.png
    :target: http://www.gnu.org/licenses/agpl-3.0-standalone.html
    :alt: License: AGPL-3
.. |badge3| image:: https://img.shields.io/badge/github-OCA%2Fvertical--cooperative-lightgray.png?logo=github
    :target: https://github.com/OCA/vertical-cooperative/tree/12.0/easy_my_coop_easy_migration
    :alt: OCA/vertical-cooperative
.. |badge4| image:: https://img.shields.io/badge/weblate-Translate%20me-F47D42.png
    :target: https://translation.odoo-community.org/projects/vertical-cooperative-12-0/vertical-cooperative-12-0-easy_my_coop_easy_migration
    :alt: Translate me on Weblate

|badge1| |badge2| |badge3| |badge4| 

This project aim to facilitate the migration from other ERP to Odoo with EMC application:

 - Add new field to SubscriptionRequest to save the migrated cooperator number.

Please don't hesitate to suggest one of your modules to this project.

**Table of contents**

.. contents::
   :local:

Installation
============

## Deploying with pip

We used [odoo setup tools](https://pypi.org/project/setuptools-odoo/#packaging-a-single-addon) to generate the pypi files from the odoo manifests. To deploy any packaged module, so that odoo can later install them,
you can create a venv with this name (it's git-ignored)
```shell
python -m venv venv
```
And then pip-install them [from pypi](https://pypi.org/user/coopdevs/).

### Example

For instance, for the addon `easy_my_coop_easy_migration`
```shell
pip install odoo12-addon-easy-my-coop-easy-migration==12.0.1.0.0
```
Beware that for word separation, pypi uses dashes `-` and odoo underscores `_`.

Bug Tracker
===========

Bugs are tracked on `GitHub Issues <https://github.com/OCA/vertical-cooperative/issues>`_.
In case of trouble, please check there if your issue has already been reported.
If you spotted it first, help us smashing it by providing a detailed and welcomed
`feedback <https://github.com/OCA/vertical-cooperative/issues/new?body=module:%20easy_my_coop_easy_migration%0Aversion:%2012.0%0A%0A**Steps%20to%20reproduce**%0A-%20...%0A%0A**Current%20behavior**%0A%0A**Expected%20behavior**>`_.

Do not contact contributors directly about support or help with technical issues.

Credits
=======

Authors
~~~~~~~

* Coopdevs Treball SCCL

Contributors
~~~~~~~~~~~~

* Coopdevs Treball SCCL

Maintainers
~~~~~~~~~~~

This module is maintained by the OCA.

.. image:: https://odoo-community.org/logo.png
   :alt: Odoo Community Association
   :target: https://odoo-community.org

OCA, or the Odoo Community Association, is a nonprofit organization whose
mission is to support the collaborative development of Odoo features and
promote its widespread use.

This module is part of the `OCA/vertical-cooperative <https://github.com/OCA/vertical-cooperative/tree/12.0/easy_my_coop_easy_migration>`_ project on GitHub.

You are welcome to contribute. To learn how please visit https://odoo-community.org/page/Contribute.
